(function () {
  'use strict';

  // Initialize store
  let store=null;
  // choose a range of different colors for node circles
  let colorScale=d3.scaleOrdinal().domain([1,10]).range(d3.schemeCategory10);
  
  // show data.json to the console
   d3.json('data.json').then( data=> {
     store=data;
     showData(store);
  console.log(store);
     
   });

  // Dimension of the container
  let svg = d3.select('#container')
    .attr('height',500)
    .attr('width',960);
   

      // let nodes, links=null
      function creatElements(data){
        // Attributes of nodes
         let nodes=svg.append('g')
         .attr('class','nodes')
         .selectAll('circle')
         .data(data.nodes)
         .enter()
         .append('circle') // Shape
         .attr('r',15) // radius of each node circle
         .attr('fill', d=> colorScale(d.group)); // Colors represent different groups
         
        // Attributes of links
         let links=svg.append('g')
         .attr('class','links')
         .selectAll('line')
         .data(data.links)
         .enter()
         .append('line') // Shape
         .style("stroke",'black') // Stroke value and color
        .style("stroke-width",d=> +d.value/20); // Max value
         
      }
  
  		// Nodes and links are automatically updated if data is modified
      function updateElements(){

        d3.select('.nodes')
        .selectAll('circle')
        .attr('cx', d=>d.x)
        .attr('cy', d=>d.y);
        
        d3.select('.links')
        .selectAll('line')
        .attr('x1', d=>d.source.x)
        .attr('y1', d=>d.source.y)
        .attr('x2', d=>d.target.x)
        .attr('y2', d=>d.target.y); 
      }
  
    function showData(data){
      // Screen dimension
        let height = 500;
        let width = 960;

       creatElements(data);
				
      // How sensitively the network will move if dragged by a mouse
        let simulation= d3.forceSimulation()
          .force('link',d3.forceLink().id(function(d){   
            return d.id;
               }))
          .force('charge',d3.forceManyBody().strength(-400))
          .force('center',d3.forceCenter(width/2,height/2));
         
          simulation.nodes(data.nodes)
          .on('tick', updateElements); 
          simulation.force('link').links(data.links);
      }

}());
